==> zio-aws-sagemaker_3-5.17.146.1-sources.jar: zio/aws/sagemaker/model/ProfilerConfigForUpdate.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.{
  ProfilingIntervalInMilliseconds,
  ConfigValue,
  S3Uri,
  DisableProfiler,
  ConfigKey
}
import scala.jdk.CollectionConverters.*
final case class ProfilerConfigForUpdate(
    s3OutputPath: Option[S3Uri] = None,
    profilingIntervalInMilliseconds: Option[ProfilingIntervalInMilliseconds] =
      None,
    profilingParameters: Option[Map[ConfigKey, ConfigValue]] = None,
    disableProfiler: Option[DisableProfiler] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate = {
    import ProfilerConfigForUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
      .builder()
      .optionallyWith(
        s3OutputPath.map(value => S3Uri.unwrap(value): java.lang.String)
      )(_.s3OutputPath)
      .optionallyWith(
        profilingIntervalInMilliseconds.map(value =>
          ProfilingIntervalInMilliseconds.unwrap(value): java.lang.Long
        )
      )(_.profilingIntervalInMilliseconds)
      .optionallyWith(
        profilingParameters.map(value =>
          value
            .map({ case (key, value) =>
              (ConfigKey.unwrap(key): java.lang.String) -> (ConfigValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.profilingParameters)
      .optionallyWith(
        disableProfiler.map(value =>
          DisableProfiler.unwrap(value): java.lang.Boolean
        )
      )(_.disableProfiler)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly =
    zio.aws.sagemaker.model.ProfilerConfigForUpdate.wrap(buildAwsValue())
}
object ProfilerConfigForUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ProfilerConfigForUpdate =
      zio.aws.sagemaker.model.ProfilerConfigForUpdate(
        s3OutputPath.map(value => value),
        profilingIntervalInMilliseconds.map(value => value),
        profilingParameters.map(value => value),
        disableProfiler.map(value => value)
      )
    def s3OutputPath: Option[S3Uri]
    def profilingIntervalInMilliseconds: Option[ProfilingIntervalInMilliseconds]
    def profilingParameters: Option[Map[ConfigKey, ConfigValue]]
    def disableProfiler: Option[DisableProfiler]
    def getS3OutputPath: ZIO[Any, AwsError, S3Uri] =
      AwsError.unwrapOptionField("s3OutputPath", s3OutputPath)
    def getProfilingIntervalInMilliseconds
        : ZIO[Any, AwsError, ProfilingIntervalInMilliseconds] =
      AwsError.unwrapOptionField(
        "profilingIntervalInMilliseconds",
        profilingIntervalInMilliseconds
      )
    def getProfilingParameters
        : ZIO[Any, AwsError, Map[ConfigKey, ConfigValue]] =
      AwsError.unwrapOptionField("profilingParameters", profilingParameters)
    def getDisableProfiler: ZIO[Any, AwsError, DisableProfiler] =
      AwsError.unwrapOptionField("disableProfiler", disableProfiler)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ) extends zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly {
    override val s3OutputPath: Option[S3Uri] = scala
      .Option(impl.s3OutputPath())
      .map(value => zio.aws.sagemaker.model.primitives.S3Uri(value))
    override val profilingIntervalInMilliseconds
        : Option[ProfilingIntervalInMilliseconds] = scala
      .Option(impl.profilingIntervalInMilliseconds())
      .map(value =>
        zio.aws.sagemaker.model.primitives
          .ProfilingIntervalInMilliseconds(value)
      )
    override val profilingParameters: Option[Map[ConfigKey, ConfigValue]] =
      scala
        .Option(impl.profilingParameters())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.sagemaker.model.primitives.ConfigKey(
                key
              ) -> zio.aws.sagemaker.model.primitives.ConfigValue(value)
            })
            .toMap
        )
    override val disableProfiler: Option[DisableProfiler] = scala
      .Option(impl.disableProfiler())
      .map(value => zio.aws.sagemaker.model.primitives.DisableProfiler(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ): zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-6.20.103.1-sources.jar: zio/aws/sagemaker/model/ProfilerConfigForUpdate.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  ProfilingIntervalInMilliseconds,
  ConfigValue,
  S3Uri,
  DisableProfiler,
  ConfigKey
}
import scala.jdk.CollectionConverters.*
final case class ProfilerConfigForUpdate(
    s3OutputPath: Optional[S3Uri] = Optional.Absent,
    profilingIntervalInMilliseconds: Optional[ProfilingIntervalInMilliseconds] =
      Optional.Absent,
    profilingParameters: Optional[Map[ConfigKey, ConfigValue]] =
      Optional.Absent,
    disableProfiler: Optional[DisableProfiler] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate = {
    import ProfilerConfigForUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
      .builder()
      .optionallyWith(
        s3OutputPath.map(value => S3Uri.unwrap(value): java.lang.String)
      )(_.s3OutputPath)
      .optionallyWith(
        profilingIntervalInMilliseconds.map(value =>
          ProfilingIntervalInMilliseconds.unwrap(value): java.lang.Long
        )
      )(_.profilingIntervalInMilliseconds)
      .optionallyWith(
        profilingParameters.map(value =>
          value
            .map({ case (key, value) =>
              (ConfigKey.unwrap(key): java.lang.String) -> (ConfigValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.profilingParameters)
      .optionallyWith(
        disableProfiler.map(value =>
          DisableProfiler.unwrap(value): java.lang.Boolean
        )
      )(_.disableProfiler)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly =
    zio.aws.sagemaker.model.ProfilerConfigForUpdate.wrap(buildAwsValue())
}
object ProfilerConfigForUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ProfilerConfigForUpdate =
      zio.aws.sagemaker.model.ProfilerConfigForUpdate(
        s3OutputPath.map(value => value),
        profilingIntervalInMilliseconds.map(value => value),
        profilingParameters.map(value => value),
        disableProfiler.map(value => value)
      )
    def s3OutputPath: Optional[S3Uri]
    def profilingIntervalInMilliseconds
        : Optional[ProfilingIntervalInMilliseconds]
    def profilingParameters: Optional[Map[ConfigKey, ConfigValue]]
    def disableProfiler: Optional[DisableProfiler]
    def getS3OutputPath: ZIO[Any, AwsError, S3Uri] =
      AwsError.unwrapOptionField("s3OutputPath", s3OutputPath)
    def getProfilingIntervalInMilliseconds
        : ZIO[Any, AwsError, ProfilingIntervalInMilliseconds] =
      AwsError.unwrapOptionField(
        "profilingIntervalInMilliseconds",
        profilingIntervalInMilliseconds
      )
    def getProfilingParameters
        : ZIO[Any, AwsError, Map[ConfigKey, ConfigValue]] =
      AwsError.unwrapOptionField("profilingParameters", profilingParameters)
    def getDisableProfiler: ZIO[Any, AwsError, DisableProfiler] =
      AwsError.unwrapOptionField("disableProfiler", disableProfiler)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ) extends zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly {
    override val s3OutputPath: Optional[S3Uri] = zio.aws.core.internal
      .optionalFromNullable(impl.s3OutputPath())
      .map(value => zio.aws.sagemaker.model.primitives.S3Uri(value))
    override val profilingIntervalInMilliseconds
        : Optional[ProfilingIntervalInMilliseconds] = zio.aws.core.internal
      .optionalFromNullable(impl.profilingIntervalInMilliseconds())
      .map(value =>
        zio.aws.sagemaker.model.primitives
          .ProfilingIntervalInMilliseconds(value)
      )
    override val profilingParameters: Optional[Map[ConfigKey, ConfigValue]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.profilingParameters())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.sagemaker.model.primitives.ConfigKey(
                key
              ) -> zio.aws.sagemaker.model.primitives.ConfigValue(value)
            })
            .toMap
        )
    override val disableProfiler: Optional[DisableProfiler] =
      zio.aws.core.internal
        .optionalFromNullable(impl.disableProfiler())
        .map(value => zio.aws.sagemaker.model.primitives.DisableProfiler(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ProfilerConfigForUpdate
  ): zio.aws.sagemaker.model.ProfilerConfigForUpdate.ReadOnly = new Wrapper(
    impl
  )
}
